==> Task-BeLike-RSRCHBOY-0.003.tar.gz: Task-BeLike-RSRCHBOY-0.003/lib/Task/BeLike/RSRCHBOY.pm <==
#
# This file is part of Task-BeLike-RSRCHBOY
#
# This software is Copyright (c) 2011 by Chris Weyl.
#
# This is free software, licensed under:
#
#   The GNU Lesser General Public License, Version 2.1, February 1999
#
package Task::BeLike::RSRCHBOY;
{
  $Task::BeLike::RSRCHBOY::VERSION = '0.003';
}

# ABSTRACT: Modules RSRCHBOY uses!

!!42;



=pod

=head1 NAME

Task::BeLike::RSRCHBOY - Modules RSRCHBOY uses!

=head1 VERSION

version 0.003

=head1 TASK CONTENTS

=head2 CPAN/GitHub Tools

=head3 L<App::cpanminus>

=head3 L<App::cpanoutdated>

=head3 L<App::gh>

=head3 L<Dist::Zilla> 4

=head3 L<Dist::Zilla::PluginBundle::RSRCHBOY>

=head3 L<Git::CPAN::Patch>

=head2 DB bits

=head3 L<DBD::SQLite> 1.31

=head3 L<DBIx::Class> 0.08192

=head3 L<DBIx::Class::Schema::Loader> 0.07010

=head3 L<DBIx::Class::Migration>

=head2 Date/Time handling

=head3 L<DateTime>

=head3 L<DateTime::Format::DB2>

=head3 L<DateTime::Format::DBI>

=head3 L<DateTime::Format::MySQL>

=head3 L<DateTime::Format::Pg>

=head2 Hygiene

=head3 L<common::sense>

=head3 L<namespace::autoclean>

=head3 L<Perl::Tidy>

=head3 L<Perl::Critic>

=head2 Class bits

=head3 L<Class::Method::Modifiers>

=head3 L<Role::Basic>

=head3 L<Reindeer> 0.008

=head3 L<MooseX::App::Cmd>

=head3 L<MooseX::AutoDestruct> 0.007

=head3 L<MooseX::TrackDirty::Attributes> 2.000

Version 2.000 required because: native traits support

=head3 L<MooseX::Types::Perl>

=head2 Testing

=head3 L<Test::Moose::More> 0.009

=head3 L<Test::Routine> 0.015

=head2 Other Libraries I Use

=head3 L<aliased>

=head3 L<opts> 0.05

=head3 L<Capture::Tiny>

=head3 L<Config::JFDI>

=head3 L<File::chdir>

=head3 L<File::Slurp> 9999.18

=head3 L<Path::Class>

=head3 L<Smart::Args>

=head3 L<Smart::Comments>

=head3 L<Sub::Install>

=head3 L<Sub::Exporter>

=head3 L<Try::Tiny>

=head3 L<V>

=head1 SEE ALSO

L<Task::BeLike::RSRCHBOY::Web>

=head1 AUTHOR

Chris Weyl <cweyl@alumni.drew.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2011 by Chris Weyl.

This is free software, licensed under:

  The GNU Lesser General Public License, Version 2.1, February 1999

=cut


__END__

==> Task-BeLike-RSRCHBOY-0.004.tar.gz: Task-BeLike-RSRCHBOY-0.004/lib/Task/BeLike/RSRCHBOY.pm <==
#
# This file is part of Task-BeLike-RSRCHBOY
#
# This software is Copyright (c) 2011 by Chris Weyl.
#
# This is free software, licensed under:
#
#   The GNU Lesser General Public License, Version 2.1, February 1999
#
package Task::BeLike::RSRCHBOY;
{
  $Task::BeLike::RSRCHBOY::VERSION = '0.004';
}

# ABSTRACT: Modules RSRCHBOY uses!

!!42;

__END__

=pod

=head1 NAME

Task::BeLike::RSRCHBOY - Modules RSRCHBOY uses!

=head1 VERSION

version 0.004

=head1 TASK CONTENTS

=head2 CPAN/GitHub Tools

=head3 L<local::lib>

=head3 L<Pod::Cpandoc>

=head3 L<App::cpanminus>

=head3 L<App::cpanoutdated>

=head3 L<App::gh>

=head3 L<CPAN::Mini>

=head3 L<CPAN::Mini::Inject>

=head3 L<Dist::Zilla> 4

=head3 L<Dist::Zilla::PluginBundle::RSRCHBOY>

=head3 L<Git::CPAN::Patch>

=head2 DB bits

=head3 L<DBD::SQLite> 1.31

=head3 L<DBIx::Class> 0.08192

=head3 L<DBIx::Class::Schema::Loader> 0.07010

=head3 L<DBIx::Class::Migration>

=head2 Date/Time handling

=head3 L<DateTime>

=head3 L<DateTime::Format::DB2>

=head3 L<DateTime::Format::DBI>

=head3 L<DateTime::Format::MySQL>

=head3 L<DateTime::Format::Pg>

=head2 Hygiene

=head3 L<common::sense>

=head3 L<namespace::autoclean>

=head3 L<Perl::Tidy>

=head3 L<Perl::Critic>

=head2 Class bits

=head3 L<Class::Method::Modifiers>

=head3 L<Role::Basic>

=head3 L<Reindeer> 0.016

=head3 L<MooseX::App::Cmd>

=head3 L<MooseX::AutoDestruct> 0.007

=head3 L<MooseX::RelatedClasses>

=head3 L<MooseX::TrackDirty::Attributes> 2.000

Version 2.000 required because: native traits support

=head3 L<MooseX::Types::Perl>

=head2 Testing

=head3 L<Directory::Scratch>

=head3 L<Test::Moose::More> 0.017

=head3 L<Test::Routine> 0.015

=head3 L<Test::TempDir>

=head2 Other Libraries I Use

=head3 L<autodie> 0.16

=head3 L<autobox::Core>

=head3 L<autobox::dump>

=head3 L<autobox::JSON>

=head3 L<Moose::Autobox>

=head3 L<aliased>

=head3 L<lib::if::dev>

=head3 L<opts> 0.05

=head3 L<Capture::Tiny>

=head3 L<Config::JFDI>

=head3 L<File::chdir>

=head3 L<File::Slurp> 9999.18

=head3 L<Path::Class>

=head3 L<Smart::Args>

=head3 L<Smart::Comments>

=head3 L<Sub::Install>

=head3 L<Sub::Exporter>

=head3 L<Try::Tiny>

=head2 Helpers

=head3 L<Regexp::Debugger>

=head3 L<V>

=for :stopwords autoboxing

=head1 SEE ALSO

L<Task::BeLike::RSRCHBOY::Web>

=head1 AUTHOR

Chris Weyl <cweyl@alumni.drew.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2011 by Chris Weyl.

This is free software, licensed under:

  The GNU Lesser General Public License, Version 2.1, February 1999

=cut
